% fmri_bpfilter() - performing the idea band-pass filter on fMRI
%                   BOLD signals.
%
% See also: eegfilt()
%
% Notes: - This program allows user to input high and low cut-off
%          freq. interactively.
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function fmri_bpfilter

global FMRI

str = sprintf('%5.2f',1/FMRI.tr/2);

prompt = {'Low cut-off freq. ( >=0 ):',...
          ['High cut-off freq. ( <= ' str '):']};
defs = {'0',str};
a = inputdlg(prompt,'Input Cut-Off Freq.',1,defs);
fl = str2num(char(a(1)));
fh = str2num(char(a(2)));
FMRI.data = reshape(FMRI.data,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z,FMRI.timepoint+FMRI.dummy);
sz = size(FMRI.data);
dd = zeros(sz);
for i=1:sz(1)
  temp = FMRI.data(i,:);
  if fl == 0,
    temp2 = eegfilt(temp,1/FMRI.tr,fl,fh);
    dd(i,:) = temp2;
  else
    f_temp = fft(temp);
    f_temp2 = f_temp;
    tpl = round(fl*FMRI.timepoint/FMRI.tr);
    tph = round(fh*FMRI.timepoint/FMRI.tr);
    if tpl == 0, %low pass filter
      f_temp2(tph+1:FMRI.timepoint-tph) = complex(0,0);
    else
      f_temp2(1:tpl-1) = complex(0,0);
      f_temp2(tph+1:FMRI.timepoint-tph) = complex(0,0);
      f_temp2(FMRI.timepoint-tpl+1:FMRI.timepoiont) = complex(0,0);
    end 
    temp2 = ifft(f_temp2);
    dd(i,:) = real(temp2);
  end
  progressbar(i/sz(1));
end
progressbar(nan);

FMRI.data = dd;
FMRI.processed = [FMRI.processed ':bandpass_filtered'];
show_parameters

