% h() - history function.           
%
% Usage:
%   >> h( arg );
%
% Inputs:
%   With no argument, it return the command history.
%   arg is a string    - With a string argument it pulls the command 
%                        onto the stack.
%   arg is a number>0  - Execute the element in the stack at the 
%                        required position.
%   arg is a number<0  - Unstack the required number of elements
%   arg is 0           - Clear stack
%
% Global variables used:
%   LASTCOM   - last command
%   ALLCOM    - all the commands   

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, 2001

% This program is free software; you can redistribute it and/or
% modify it.  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

% To increase/decrease the depth of the stack, edit the eegconst file
 
function h( command );

try
	eegglobal;
	eegconst;
catch
	global LASTCOM;
	global ALLCOM;
end;

if nargin < 1
	if isempty(ALLCOM)
		fprintf('No history\n');
	else	
		for index = 1:length(ALLCOM)
			txt = ALLCOM{ index };
			if length(txt) > 72
				fprintf('%d: %s...\n', index, txt(1:70) );
			else
				fprintf('%d: %s\n', index, txt );
			end;				
		end;
	end;	
else
	if isstr( command )
		if isempty(ALLCOM)
			ALLCOM = { command };
		else	
			ALLCOM          = { command ALLCOM{:}};
		end;	
		LASTCOM         = command;
	else	
		if command == 0
			ALLCOM = [];
		else if command < 0
				ALLCOM = ALLCOM( -command+1:end ); % unstack elements
				h;
			else
				txt = ALLCOM{command};
				if length(txt) > 72
					fprintf('%s...\n', txt(1:70) );
				else
					fprintf('%s\n', txt );
				end;				
				evalin( 'base', ALLCOM{command} ); % execute element
				h( ALLCOM{command} );    % add to history
			end;
		end;	
	end;		
end;
