% jr_color() - specify the colormap used to display the functional
%              region of activity (ROA). 
%
% Usage: 
%   >> jr_color(met, colors);
%
% Inputs: 
%   met - integer (1 - 5) used to specify the method to set the
%         colormap, default = 2
%
% Optional Inputs:
%   colors - user defined colormap (N by 3) matrix
%
% See also: colormap(), image(), imagesc()
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function jr_color(met, colors)

if met == 1
   tmp = zeros(64, 3);
   a = linspace(1,0.3,32);
   tmp(1:32, 3) = a';
   a = linspace(0.3,1,32);
   tmp(33:64, 1) = a';
   colormap([gray(64); tmp]);
end

if met == 5
   tmp = zeros(64, 3);
   a = linspace(0.2,1,64);
   tmp(1:64, 1) = a';
   colormap([gray(64); jet(64)]);
end

if met == 2
   tmp = zeros(64, 3);
   a = linspace(0.2,1,64);
   tmp(1:64, 1) = a';
   a = jet(64);
   b = zeros(size(a));
   for i=1:28
     b(i,:) = a(32-i+1,:);
   end
   j = 0;
   for i=37:64
     b(i,:) = a(64-j,:);
     j = j+1;
   end
   colormap([gray(64); b]);
end

if met == 3
  tmp = zeros(64, 3); 
  colormap([gray(64); jet(64)]);
end

if met == 4
  tmp = zeros(64, 3);
  gap = fix(64/colors);
  b = [];
  for i=1:colors
    a = linspace(0.2, 1, gap);
    switch(i)
      case 1
        tmp(1+(i-1)*gap:i*gap, 1) = a';
      case 2
        tmp(1+(i-1)*gap:i*gap, 2) = a';
      case 3
        tmp(1+(i-1)*gap:i*gap, 3) = a';
      case 4
        tmp(1+(i-1)*gap:i*gap, 1) = a';
        tmp(1+(i-1)*gap:i*gap, 2) = a';
      case 5
        tmp(1+(i-1)*gap:i*gap, 1) = a';
        tmp(1+(i-1)*gap:i*gap, 3) = a';
      case 6
        tmp(1+(i-1)*gap:i*gap, 2) = a';
        tmp(1+(i-1)*gap:i*gap, 3) = a';
    end
  end
  colormap([gray(64); tmp]);
end
