% set_struc_info() - setup the information of structural images, which will be 
%                    incoperated in the fmr data structure
% 
% Usage:
%   >> set_struf_info(action);
%
% Inputs:
%   action - 'initialize': initialize the graphic user interface
%            for set_struc_info()
%          - 'cancel': cancel the editing and discard the changes
%          - 'ok': accept the changes and save then into FMRI data
%            structure
%          - 'fileselection': popup the file selection window to
%            select file.
% 
% See also: set_fmri_global_ui(), modify_param(), reselect_fmri()
%
% Notes: - Structural images might be necessary if the user wants
%          to normalize the functional images as well as resulting ICA
%          component maps (or ROAs) to the standard (Talaraich) brain
%          template for better visualization.
%        - Structural images are also needed by the function
%          map_on_struc().
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


function set_struc_info(action)
  
% This function is called within 'set_fmri_global_ui' function
% to setup the information of structural images, which will be 
% incoperated in the fmr data structure.
%
% Jeng-Ren Duann, CNL/Salk Inst., 2002-05-21
  
  global FMRI
  
  lw = 120;
  lh = 25;
  lg = 10;
  POS = get(0,'screensize');
  
  if nargin < 1,
    action = 'initialize';
  end
  
  if strcmp(action,'initialize'),
    fg1 = findobj('name','Information for Structural Images');
    if isempty(fg1)
      fg1 = figure(...
	  'name','Information for Structural Images',...
	  'numbertitle','off',...
	  'doublebuffer','on',...
	  'color','white',...
	  'backingstore','off');
      pos = get(fg1,'position');
      pos(1) = (POS(3)-pos(3))/2;
      pos(2) = 50;
      pos(3) = lw*4+25+lg*5;
      pos(4) = lh*6+lg*7;
      set(fg1,'position',pos);
      
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01 pos(4)*0.85 lw lh],...
	  'string','Filename: ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01 pos(4)*0.85-(lh+lg) lw lh],...
	  'string','Filepath: ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01 pos(4)*0.85-(lh+lg)*2 lw lh],...
	  'string','Image width (voxel): ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01 pos(4)*0.85-(lh+lg)*3 lw lh],...
	  'string','Image height (voxel): ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01 pos(4)*0.85-(lh+lg)*4 lw lh],...
	  'string','Image depth: ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+(lw+lg) pos(4)*0.85 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_filename',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+(lw+lg) pos(4)*0.85-(lh+lg) lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_pathname',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+(lw+lg) pos(4)*0.85-(lh+lg)*2 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_image_width',...
	  'string','256',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+(lw+lg) pos(4)*0.85-(lh+lg)*3 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_image_height',...
	  'string','256',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+(lw+lg) pos(4)*0.85-(lh+lg)*4 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_image_depth',...
	  'string','10',...
	  'horizontalalignment','right');
      
      uicontrol(...
	  'style','pushbutton',...
	  'position',[pos(1)*0.01+(lw+lg)*2-5 pos(4)*0.85 30 lh],...
	  'string','...',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14,...
	  'tag','btn_select_file',...
	  'callback','set_struc_info(''fileselection'')');

      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01+30+(lw+lg)*2 pos(4)*0.85 lw lh],...
	  'string','FOV X (mm): ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01+30+(lw+lg)*2 pos(4)*0.85-(lh+lg) lw lh],...
	  'string','FOV Y (mm): ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol(...
	  'style','text',...
	  'position',[pos(3)*0.01+30+(lw+lg)*2 pos(4)*0.85-(lh+lg)*2 lw lh],...
	  'string','Slice thickness (mm): ',...
	  'backgroundcolor',[.8 .8 .8],...
	  'fontsize',14);
      uicontrol('style','checkbox',...
	      'position',[pos(3)*0.01+(lw+lg)*2+30 pos(4)*0.85-(lh+lg)*3 lw lh],...
	      'string','Flip image',...
	      'backgroundcolor',[.8 .8 .8],...
	      'fontsize',14,...
		'value',1,...
	      'tag','check_flip');
      
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+30+(lw+lg)*3 pos(4)*0.85-(lh+lg)*0 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_fov_x',...
	  'string','250',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+30+(lw+lg)*3 pos(4)*0.85-(lh+lg)*1 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_fov_y',...
	  'string','250',...
	  'horizontalalignment','right');
      uicontrol(...
	  'style','edit',...
	  'position',[pos(1)*0.01+30+(lw+lg)*3 pos(4)*0.85-(lh+lg)*2 lw lh],...
	  'backgroundcolor',[1 1 1],...
	  'fontsize',14,...
	  'tag','edit_thickness',...
	  'string','7',...
	  'horizontalalignment','right');
      uicontrol('style','checkbox',...
	      'position',[pos(3)*0.01+(lw+lg)*3+30 pos(4)*0.84-(lh+lg)*3 lw lh],...
	      'string','Resort image',...
	      'backgroundcolor',[.8 .8 .8],...
	      'fontsize',14,...
	      'tag','check_resort');
      
      uicontrol(...
	  'style','pushbutton',...
	  'position',[pos(1)*0.01+(lw+lg)*1 pos(4)*0.85-(lh+lg)*5 lw lh],...
	  'string','OK',...
	  'fontsize',14,...
	  'tag','btn_OK',...
	  'callback','set_struc_info(''ok'')',...
	  'backgroundcolor',[.8 .8 .8]);
      uicontrol(...
	  'style','pushbutton',...
	  'position',[pos(1)*0.01+30+(lw+lg)*2 pos(4)*0.85-(lh+lg)*5 lw lh],...
	  'string','Cancel',...
	  'fontsize',14,...
	  'tag','btn_cancel',...
	  'callback','set_struc_info(''cancel'')',...
	  'backgroundcolor',[.8 .8 .8]);
    end
    
  elseif strcmp(action,'cancel'),
    FMRI.struc_name = '';
    FMRI.struc_path = '';
    FMRI.struc_image_width = [];
    FMRI.struc_image_height = [];
    FMRI.struc_image_depth = [];
    FMRI.struc_fov_x = [];
    FMRI.struc_fov_y = [];
    FMRI.struc_slicetk = [];
    FMRI.struc_flip = [];
    FMRI.struc_resort = [];
    
    h1 = findobj('name','Information for Structural Images');
    if ~isempty(h1);
      close(h1);
    end
    
    str = sprintf(['Structural image information not available\nto' ...
		   [' edit this information, please use Modify' ...
		    ' Structural Info under Dataset menu']]);
    errordlg(str);
    
  elseif strcmp(action,'ok'),
    h1 = findobj('tag','edit_filename');
    str = get(h1,'string');
    FMRI.struc_name = str;
    h1 = findobj('tag','edit_pathname');
    str = get(h1,'string');
    FMRI.struc_path = str;
    h1 = findobj('tag','edit_image_width');
    str = get(h1,'string');
    FMRI.struc_image_width = str2num(str);
    h1 = findobj('tag','edit_image_height');
    str = get(h1,'string');
    FMRI.struc_image_height = str2num(str);
    h1 = findobj('tag','edit_image_depth');
    str = get(h1,'string');
    FMRI.struc_image_depth = str2num(str);
    h1 = findobj('tag','edit_fov_x');
    str = get(h1,'string');
    FMRI.struc_fov_x = str2num(str);
    h1 = findobj('tag','edit_fov_y');
    str = get(h1,'string');
    FMRI.struc_fov_y = str2num(str);
    h1 = findobj('tag','edit_thickness');
    str = get(h1,'string');
    FMRI.struc_slicetk = str2num(str);
    h1 = findobj('tag','check_flip');
    FMRI.struc_flip = get(h1,'value');
    h1 = findobj('tag','check_resort');
    FMRI.struc_resort = get(h1,'value');
    
    h1 = findobj('name','Information for Structural Images');
    if ~isempty(h1);
      close(h1);
    end
    
  elseif strcmp(action,'fileselection'),
    [fname,pname] = uigetfile({'*','All Files (*)'},'Pick a file');
    if ~isempty(fname),
      h1 = findobj('tag','edit_filename');
      set(h1,'string',fname);
      h1 = findobj('tag','edit_pathname');
      set(h1,'string',pname);
    end
    
  end
  