% temporal_smooth() - perform 3 time-point moving average on
%                     fMRI time series.
% 
% Usage:
%   >> temporal_smooth;
%
% See also: spatial_smooth(), rm_slice()
%
% Notes: - temporal_smooth() is not recommended for the common data
%          analysis of fMRI data using ICA, especially infomax ICA,
%          unless the fMRI time series looks fairly noisy in time domain. 
%        - temporal_smooth() applies only 3 time-point moving average
%          on the time course of each voxel. 
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


function temporal_smooth()
  
  global FMRI
  
  FMRI.data = reshape(FMRI.data,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z, ...
		      FMRI.timepoint);
  temp = FMRI.data;
  progressbar(0.01);
  for i=1:FMRI.dime_x*FMRI.dime_y*FMRI.dime_z,
    for j=2:FMRI.timepoint-1,
      temp(i,j) = mean(FMRI.data(i,j-1:j+1));
    end
    if mod(i,1000) == 0,
      progressbar(i/FMRI.dime_x/FMRI.dime_y/FMRI.dime_z);
    end
  end
  FMRI.data = reshape(temp,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z*FMRI.timepoint,1);
  progressbar(nan);  
  FMRI.processed = [FMRI.processed ':temporal_smoothed'];
  show_parameters