function map_on_fmri

global FMRI

component_displayed = 1;

% finding the component maps
W = FMRI.icaweight * FMRI.icasphere;
invW = pinv(W);
u = W * FMRI.data;

% use the training data set and the index of inside-brain voxels to 
% construct the functional images used to overlay the component map
avg_image = mean(FMRI.data);
base_image = zeros(1,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx),
  base_image(FMRI.idx(i)) = avg_image(i);
end
base_image = reshape(base_image,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
disp_row = floor(sqrt(FMRI.dime_z));
disp_col = ceil(sqrt(FMRI.dime_z));
h0 = figure('name',  'ICA Component Map on Functional Images', ...
            'units', 'normalized');

ih = []; % create image hendle for each image patch
for i=1:FMRI.dime_z,
  a = floor(i/disp_col);
  b = mod(i,disp_col);
  ii = tightsubplot(disp_row,disp_col,a*disp_col+b);
  imagesc(base_image(:,:,i)');
  axis off
  axis image
  ih = [ih ii];
end
colormap(gray);

ed_title = uicontrol('style','edit', ...
                     'string','ICA component map', ...
                     'foregroundcolor', [0 0 1], ...
                     'fontsize', 14, ...
                     'backgroundcolor', [1 1 1]);
pos = get(ed_title, 'position');
set(ed_title, 'position', [pos(1) pos(2) 200 25]);
pos = get(ed_title, 'position');
bt0 = uicontrol('style',    'pushbutton', ...
                 'string',   'Previous', ...
                 'fontsize', 14, ...
                 'position', [pos(1)+pos(3)+20 pos(2) 100 25]);
pos = get(bt0,'position');
set(bt0,'position',pos);
bt1 = uicontrol('style',     'pushbutton', ...
                'string',    'Next', ...
                'fontsize',  14, ...
                'position', [pos(1)+pos(3)+20 pos(2) 100 25], ...
                'callback', next_component);

display_component_map(h0,ih,u,component_displayed);


%===========================================
function display_component_map(h0,ih,u,comp)
%===========================================
% display the component map on the functional images
% according to the local variable 'component_displayed'

global FMRI

avg_image = mean(FMRI.data);
base_image = zeros(1,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx),
  base_image(FMRI.idx(i)) = avg_image(i);
end
base_image = reshape(base_image,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);

a = findobj(h0,'style','edit');
set(a,'string',['Component #' int2str(comp)]);
temp_data = u(comp, :);
mean_temp_data = mean(temp_data);
std_temp_data = std(temp_data);

uthre =  mean_temp_data + 1.5*std_temp_data;
uidx = find(temp_data > uthre);
umap = zeros(1, length(temp_data));
umap(uidx) = temp_data(uidx);
draw_max = max(umap(uidx))/std_temp_data/2;
umap(uidx) = log10(1+umap(uidx)-mean_temp_data);
ubound = max(umap(uidx));
lbound = min(umap(uidx));
umap(uidx) = (umap(uidx)-lbound)*32/(ubound-lbound) + 100;
uimg = zeros(FMRI.dime_x*FMRI.dime_y*FMRI.dime_z, 1);
for i=1:length(FMRI.idx)
  uimg(FMRI.idx(i)) = umap(i);
end
uimg = reshape(uimg, FMRI.dime_x, FMRI.dime_y, FMRI.dime_z);

lthre =  mean_temp_data - 1.5*std_temp_data;
lidx = find(temp_data < lthre);
lmap = zeros(1, length(temp_data));
lmap(lidx) = temp_data(lidx);
lmap(lidx) = -1 * log10(1+lmap(lidx)-mean_temp_data);
lmap(lidx) = (lmap(lidx)-lbound)*28/(ubound-lbound) + 64 ;
limg = zeros(FMRI.dime_x*FMRI.dime_y*FMRI.dime_z, 1);
for i=1:length(FMRI.idx)
  limg(FMRI.idx(i)) = lmap(i);
end
limg = reshape(limg, FMRI.dime_x, FMRI.dime_y, FMRI.dime_z);

smap = uimg + limg;
sidx = find(smap < 64 );
smap(sidx) = 0;
sidx = find(smap >= 64 );
temp_base_image = base_image;
temp_base_image(sidx) = 0;
img = temp_base_image + smap;
 
for i=1:FMRI.dime_z,
  axes(ih(i));
  imagesc(img(:,:,i)');
  axis off
  axis image
end
jr_color(2);
figure(h0);

%=====================================
function next_component
%=====================================
disp('This is a book');

