% show_2d() - display normalized ICA component maps (or ROAs) in 2D
%           slice-by-slice display on top of normalized structural
%           images.
%
% Usage:
%   >> show_2d;
%
% See also: jr_normalize(), spm_affsub3(), show_3d(), show_mip()
%
% Notes: - Must have structural images to perform the spatial
%          normalization process.
%        - show_2d() only works on normalized ICA component maps
%          (or ROAs) and structural images.
%        - The accuracy of the spatial normalization process
%          heavily depends on the image quality and slice
%          number. Thus, the validity of the results of show_2d()
%          cannot be guaranteed. 
%        
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function show_2d

% Jeng-Ren Duann, CNL/Salk Inst., 2002-05-25

disp('Select the resulting file to display:');
[map_name, map_path] = uigetfile(...
                                 {'*.img','Analyze format ICA result'},...
				 'Select Resulting file');
if isequal(map_name,0) | isequal(map_path,0),
  errordlg('Cancelled by user...!');
  return;
end

disp('Select template file:');
[temp_name, temp_path] = uigetfile(...
  {'*.img','Analyze format image'},...
				   'Select Template');
if isequal(temp_name,0) | isequal(temp_path,0),
  errordlg('Cancelled by user...!');
  return;
end

str = sprintf('Orientation:\n1: Axial\n2: Sagittal\n3: Coronal');
prompt = {str, 'Z value range:','Slice range (ex. -26:2:20):'};
defs = {'1','[2 10]','-26:2:20'};
a = inputdlg(prompt, '2D Overlay', 1, defs);
if isempty(a),
  errordlg('Cancelled by user...!');
  return;
end

ori = str2num(char(a(1)));
z_range = str2num(char(a(2)))
slice_range = str2num(char(a(3)));
struc_file = [temp_path temp_name];
map_file = [map_path map_name];
show_actslice(struc_file, map_file, z_range, map_file, -1*z_range, ...
	      'axial',slice_range);

