% show_parameters() - display information about all data fields of
%                     FMRI data structure
%
% Usage:
%   >> show_parameters;
%
% See also: FMRI, set_fmri_global_ui(), modify_param()
%
% Notes: - Instead of showing the content of data fields, for some
%          reason, show_parameters() shows only the length or the size of
%          the data fields.
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


function show_parameters

global FMRI
global hwnd

str = sprintf('FMRI ACQUISITION PARAMETERS ...\n');
if isempty(FMRI.filename),
  str = [str sprintf('  Image file name:\n')];
else
  str = [str sprintf('  Image file name: \n    %s\n',FMRI.filename)];
end
if isempty(FMRI.pathname),
  str = [str sprintf('  Image path:\n')];
else
  str = [str sprintf('  Image path: \n    %s\n',FMRI.pathname)];
end
if isempty(FMRI.data),
  str = [str sprintf('  Data size:\n')];
else
  sz = size(FMRI.data);
  str = [str sprintf('  Data size: \n    %d x %d\n',sz(1),sz(2))];
end
if isempty(FMRI.dime_x),
  str = [str sprintf('  Image dimensions:\n')];
else
  str = [str sprintf('  Image dimensions: \n    %d x %d x %d\n',FMRI.dime_x,FMRI.dime_y,FMRI.dime_z)];
end
if isempty(FMRI.fov_x),
  str = [str sprintf('  FOV (mm):\n')];
else
  str = [str sprintf('  FOV (mm): \n    %5.2f x %5.2f\n',FMRI.fov_x,FMRI.fov_y)];
end
if isempty(FMRI.slicetk),
  str = [str sprintf('  Slice thickness (mm):\n')];
else
  str = [str sprintf('  Slice thickness (mm): \n    %5.2f\n',FMRI.slicetk)];
end
if isempty(FMRI.dummy),
  str = [str sprintf('  Dummy scans:\n')];
else
  str = [str sprintf('  Dummy scans: \n    %d\n',FMRI.dummy)];
end
if isempty(FMRI.timepoint),
  str = [str sprintf('  Time Point:\n')];
else
  str = [str sprintf('  Time Point: \n    %d\n',FMRI.timepoint)];
end
if ~isempty(FMRI.dummy) & ~isempty(FMRI.timepoint),
  str = [str sprintf('  Total scan number:\n    %d\n',FMRI.dummy+FMRI.timepoint)];
else
  str = [str sprintf('  Total scan number:\n')];
end
if isempty(FMRI.tr),
  str = [str sprintf('  TR:\n')];
else
  str = [str sprintf('  TR (sec):\n    %5.2f\n',FMRI.tr)];
end
if isempty(FMRI.idx),
  str = [str sprintf('  Index of brain voxels:\n')];
else
  str = [str sprintf('  Index of brain voxels:\n    %d\n',length(FMRI.idx))];
end

str = [str sprintf('\nICA PARAMETERS ...\n')];
if isempty(FMRI.pcano),
  str = [str sprintf('  PCA number           :\n')];
else  
  str = [str sprintf('  PCA number           : %d\n',FMRI.pcano)];
end
if isempty(FMRI.annealdeg),
  str = [str sprintf('  Annealing angle       :\n')];
else
  str = [str sprintf('  Annealing angle       : %d\n',FMRI.annealdeg)];
end
if isempty(FMRI.extended),
  str = [str sprintf('  Extended ICA used :\n')];
else
  str = [str sprintf('  Extended ICA used : %d\n',FMRI.extended)];
end

if isempty(FMRI.icasphere)
  str = [str sprintf('  Length of sphere matrix:\n')];
else
  sz = size(FMRI.icasphere);
  str = [str sprintf('  Length of sphere matrix:      %d x %d\n',sz(1),sz(2))];
end

if isempty(FMRI.icaweight)
  str = [str sprintf('  Length of weight matrix:\n')];
else
  sz = size(FMRI.icaweight);
  str = [str sprintf('  Length of weight matrix:      %d x %d\n',sz(1),sz(2))];
end

if isempty(FMRI.processed),
  str = [str sprintf('\nDATASET STATUS:\n')];
else
  str = [str sprintf('\nDATASET STATUS: \n  %s\n',FMRI.processed)];
end

h = findobj(hwnd,'tag','text1');
set(h,'string',str);








