% spatial_smooth() - perform 3 by 3 averaging mask on 2D slices of
%                    fMRI data. 
% 
% Usage:
%   >> spatial_smooth;
%
% See also: rm_slice(), temporal_smooth()
%
% Notes: - spatial_smooth() is not recommended for the common data
%          analysis of fMRI data using ICA, especially infomax ICA,
%          unless the fMRI data is fairly noisy in spatial domain. 
%        - spatial_smooth() works only in 2D slices instead of 3D
%          volume by a simple 3 by 3 averaging mask beacuse we don't
%          want too much smoothing to change the data distribution of
%          fMRI data.
%
% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


function spatial_smooth
  
  global FMRI
  global hwnd
  
  FMRI.data = reshape(FMRI.data,FMRI.dime_x,FMRI.dime_y, ...
		      FMRI.dime_z,FMRI.timepoint);
  data = FMRI.data;
  progressbar(0.5/FMRI.timepoint);
  for i=1:FMRI.timepoint,
    for j=1:FMRI.dime_z,
      for y=2:FMRI.dime_y-1,
	for x=2:FMRI.dime_x-1,
	  temp = FMRI.data(x-1:x+1,y-1:y+1,j,i);
	  temp = sort(temp(:));
	  data(x,y,j,i) = temp(5);
	end
      end
    end
    progressbar(i/FMRI.timepoint);
  end
  progressbar(nan);
  FMRI.data = reshape(data,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z*FMRI.timepoint,1);
  FMRI.processed = [FMRI.processed ':spatial_smoothed'];
  show_parameters;
  